@@ -29,7 +29,8 @@ from .lib.symengine_wrapper import (
     FunctionSymbol as AppliedUndef,
     golden_ratio as GoldenRatio,
     catalan as Catalan,
-    eulergamma as EulerGamma
+    eulergamma as EulerGamma,
+    unicode
 )
 from .utilities import var, symbols
 from .functions import *
@@ -54,9 +55,14 @@ if have_numpy:
 
     def lambdify(args, exprs, **kwargs):
         return Lambdify(args, *exprs, **kwargs)
+else:
+    def __getattr__(name):
+        if name == 'lambdify':
+            raise AttributeError("Cannot import numpy, which is required for `lambdify` to work")
+        raise AttributeError(f"module 'symengine' has no attribute '{name}'")
 
 
-__version__ = "0.8.1"
+__version__ = "0.10.0"
 
 
 # To not expose internals
